import setuptools

setuptools.setup(
    name='sgwc',
    version='1.0',
    author='Czw_96',
    author_email='459749926@qq.com',
    description='搜狗微信文章爬虫',
    url='https://github.com/Czw96/sgwc',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=[
        'lxml',
        'requests',
        'Pillow',
    ]
)
